# Mopidy HTTP frontend

This web server is a part of the music server Mopidy. To learn more about Mopidy, please visit www.mopidy.com.

## Static content serving

To see your own content instead of this placeholder page, change the setting `HTTP_SERVER_STATIC_DIR` to point to the directory containing your static files. This can be used to host e.g. a pure HTML/CSS/JavaScript Mopidy client.

If you replace this page with your own content, the Mopidy resources at /mopidy/ will still be available.